==> blancoDbEE-1.6.5-src.zip: src/blanco/cg/transformer/cs/BlancoCgSourceFileCsSourceExpander.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.cg.transformer.cs;

import java.util.ArrayList;

import blanco.cg.valueobject.BlancoCgClass;
import blanco.cg.valueobject.BlancoCgInterface;
import blanco.cg.valueobject.BlancoCgSourceFile;
import blanco.commons.util.BlancoStringUtil;

/**
 * BlancoCgSourceFile\[XR[hɓWJ܂B
 * 
 * ̃NXblancoCg̃o[IuWFNg\[XR[hgXtH[}[̌ʂ̓WJ@\łB
 * 
 * @author IGA Tosiki
 */
class BlancoCgSourceFileCsSourceExpander {
    /**
     * w肪ꍇ̃ftHg̃t@CRgB
     */
    private static final String DEFAULT_FILE_COMMENT = "̃\[XR[h blanco Frameworkɂ莩܂B";

    /**
     * ͂ƂȂ\[XR[h\B
     */
    private BlancoCgSourceFile fCgSourceFile = null;

    /**
     * ԓIɗp\[XR[h킷ArrayListBjava.lang.StringXgɊi[܂B(BlancoCgLineł͂܂B)
     * 
     * ł͐`O\[XR[hԓIɂ킦܂B
     */
    private ArrayList fSourceLines = null;

    /**
     * SourceFile琮`O\[XR[hXg𐶐܂B
     * 
     * @param argSourceFile
     *            \[XR[h킷o[IuWFNgB
     * @return \[XR[hɓWJ̃XgB
     */
    public ArrayList transformSourceFile(final BlancoCgSourceFile argSourceFile) {
        // mɃ\[Xs̃Xg܂B
        fSourceLines = new ArrayList();

        fCgSourceFile = argSourceFile;

        // \[Xt@C̃t@Cwb_[o͏܂B
        expandSourceFileHeader();

        // ̌㔼ŃC|[gҐȂ܂A̍ۂɎQƂAJ[ǉĂ܂B
        BlancoCgImportCsSourceExpander.insertAnchorString(fSourceLines);

        // pbP[W̐B
        if (BlancoStringUtil.null2Blank(fCgSourceFile.getPackage()).length() > 0) {
            fSourceLines.add("namespace " + fCgSourceFile.getPackage());
            fSourceLines.add("{");
        }

        if (fCgSourceFile.getImportList() == null) {
            throw new IllegalArgumentException("import̃Xgnull^܂B");
        }

        // C^tF[X̓WJ{܂B
        if (fCgSourceFile.getInterfaceList() == null) {
            throw new IllegalArgumentException("C^tF[X̃Xgnull^܂B");
        }
        for (int index = 0; index < fCgSourceFile.getInterfaceList().size(); index++) {
            final Object objClass = fCgSourceFile.getInterfaceList().get(index);
            if (objClass instanceof BlancoCgInterface == false) {
                throw new IllegalArgumentException("C^tF[X̃XgɃC^tF[XȊǑ^["
                        + objClass.getClass().getName() + "]̒l^܂B");
            }
            final BlancoCgInterface cgInterface = (BlancoCgInterface) objClass;
            new BlancoCgInterfaceCsSourceExpander().transformInterface(
                    cgInterface, fCgSourceFile, fSourceLines);
        }

        // NX̓WJ{܂B
        if (fCgSourceFile.getClassList() == null) {
            throw new IllegalArgumentException("NX̃Xgnull^܂B");
        }
        for (int index = 0; index < fCgSourceFile.getClassList().size(); index++) {
            final Object objClass = fCgSourceFile.getClassList().get(index);
            if (objClass instanceof BlancoCgClass == false) {
                throw new IllegalArgumentException("NX̃XgɃNXȊǑ^["
                        + objClass.getClass().getName() + "]̒l^܂B");
            }
            final BlancoCgClass cgClass = (BlancoCgClass) objClass;
            new BlancoCgClassCsSourceExpander().transformClass(cgClass,
                    fCgSourceFile, fSourceLines);
        }

        if (BlancoStringUtil.null2Blank(fCgSourceFile.getPackage()).length() > 0) {
            fSourceLines.add("}");
        }

        // import̓WJ܂B
        // ̏ANXWJɎ{Ă̂ɂ͈Ӗ܂B
        // NXWJȂǂoāA߂ăC|[g̈ꗗm肷邩łB
        new BlancoCgImportCsSourceExpander().transformImport(fCgSourceFile,
                fSourceLines);

        return fSourceLines;
    }

    /**
     * \[Xt@C̃t@Cwb_[o͏܂B
     */
    private void expandSourceFileHeader() {
        // \[Xt@Cwb_[̃Rg XbVQÓƍl܂B
        // ʉ̂₷̊ϓ_A_ł XbVRŎĂ܂B

        if (BlancoStringUtil.null2Blank(fCgSourceFile.getDescription())
                .length() > 0) {
            fSourceLines.add("/// " + fCgSourceFile.getDescription());
        } else {
            // w肪ꍇɂ̓ftHg̃Rg𗘗p܂B
            fSourceLines.add("/// " + DEFAULT_FILE_COMMENT);
        }

        // hLg̒ԕ𐶐܂B
        new BlancoCgLangDocCsSourceExpander().transformLangDocBody(
                fCgSourceFile.getLangDoc(), fSourceLines);
    }
}

==> blancoDbEE-2.2.3-src.zip: src/blanco/cg/transformer/cs/BlancoCgSourceFileCsSourceExpander.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2006 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.cg.transformer.cs;

import java.util.ArrayList;
import java.util.List;

import blanco.cg.BlancoCgSupportedLang;
import blanco.cg.util.BlancoCgLineUtil;
import blanco.cg.util.BlancoCgSourceFileUtil;
import blanco.cg.valueobject.BlancoCgClass;
import blanco.cg.valueobject.BlancoCgEnum;
import blanco.cg.valueobject.BlancoCgInterface;
import blanco.cg.valueobject.BlancoCgSourceFile;
import blanco.commons.util.BlancoStringUtil;

/**
 * BlancoCgSourceFile\[XR[hɓWJ܂B
 * 
 * ̃NXblancoCg̃o[IuWFNg\[XR[hgXtH[}[̌ʂ̓WJ@\łB
 * 
 * @author IGA Tosiki
 */
class BlancoCgSourceFileCsSourceExpander {
    /**
     * ̃NXΏۂƂvO~OB
     */
    protected static final int TARGET_LANG = BlancoCgSupportedLang.CS;

    /**
     * ͂ƂȂ\[XR[h\B
     */
    private BlancoCgSourceFile fCgSourceFile = null;

    /**
     * ԓIɗp\[XR[h킷ListBjava.lang.StringXgɊi[܂B(BlancoCgLineł͂܂B
     * )
     * 
     * ł͐`O\[XR[hԓIɂ킦܂B
     */
    private List<java.lang.String> fSourceLines = null;

    /**
     * SourceFile琮`O\[XR[hXg𐶐܂B
     * 
     * @param argSourceFile
     *            \[XR[h킷o[IuWFNgB
     * @return \[XR[hɓWJ̃XgB
     */
    public List<java.lang.String> transformSourceFile(
            final BlancoCgSourceFile argSourceFile) {
        // mɃ\[Xs̃Xg܂B
        fSourceLines = new ArrayList<java.lang.String>();

        fCgSourceFile = argSourceFile;

        // \[Xt@C̃t@Cwb_[o͏܂B
        expandSourceFileHeader();

        // ̌㔼ŃC|[gҐȂ܂A̍ۂɎQƂAJ[ǉĂ܂B
        BlancoCgImportCsSourceExpander.insertAnchorString(fSourceLines);

        // pbP[W̐B
        if (BlancoStringUtil.null2Blank(fCgSourceFile.getPackage()).length() > 0) {
            fSourceLines.add("namespace " + fCgSourceFile.getPackage());
            fSourceLines.add("{");
        }

        if (fCgSourceFile.getImportList() == null) {
            throw new IllegalArgumentException("import̃Xgnull^܂B");
        }

        // 񋓑̂̓WJ{܂B
        for (BlancoCgEnum cgEnum : fCgSourceFile.getEnumList()) {
            new BlancoCgEnumCsSourceExpander().transformEnum(cgEnum,
                    argSourceFile, fSourceLines);
        }

        // C^tF[X̓WJ{܂B
        if (fCgSourceFile.getInterfaceList() == null) {
            throw new IllegalArgumentException("C^tF[X̃Xgnull^܂B");
        }
        for (BlancoCgInterface cgInterface : fCgSourceFile.getInterfaceList()) {
            new BlancoCgInterfaceCsSourceExpander().transformInterface(
                    cgInterface, fCgSourceFile, fSourceLines);
        }

        // NX̓WJ{܂B
        if (fCgSourceFile.getClassList() == null) {
            throw new IllegalArgumentException("NX̃Xgnull^܂B");
        }
        for (BlancoCgClass cgClass : fCgSourceFile.getClassList()) {
            new BlancoCgClassCsSourceExpander().transformClass(cgClass,
                    fCgSourceFile, fSourceLines);
        }

        if (BlancoStringUtil.null2Blank(fCgSourceFile.getPackage()).length() > 0) {
            fSourceLines.add("}");
        }

        // import̓WJ܂B
        // ̏ANXWJɎ{Ă̂ɂ͈Ӗ܂B
        // NXWJȂǂoāA߂ăC|[g̈ꗗm肷邩łB
        new BlancoCgImportCsSourceExpander().transformImport(fCgSourceFile,
                fSourceLines);

        return fSourceLines;
    }

    /**
     * \[Xt@C̃t@Cwb_[o͏܂B
     */
    private void expandSourceFileHeader() {
        // \[Xt@Cwb_[̃Rg XbVQÓƍl܂B

        if (BlancoStringUtil.null2Blank(fCgSourceFile.getDescription())
                .length() > 0) {
            fSourceLines.add(BlancoCgLineUtil
                    .getSingleLineCommentPrefix(TARGET_LANG)
                    + fCgSourceFile.getDescription());
        } else {
            // w肪ꍇɂ̓ftHg̃Rg𗘗p܂B
            for (String line : BlancoCgSourceFileUtil.getDefaultFileComment()) {
                fSourceLines.add(BlancoCgLineUtil
                        .getSingleLineCommentPrefix(TARGET_LANG)
                        + line);
            }
        }

        // hLg̒ԕ𐶐܂B
        new BlancoCgLangDocCsSourceExpander().transformLangDocBody(
                fCgSourceFile.getLangDoc(), fSourceLines, true);
    }
}
